==> material-react-table-1.11.0.tgz: package/src/_locales/fi.ts <==
import type { MRT_Localization } from '../MaterialReactTable';

export const MRT_Localization_FI: MRT_Localization = {
  actions: 'Toiminnot',
  and: 'ja',
  cancel: 'Peruuta',
  changeFilterMode: 'Muuta suodattimen tilaa',
  changeSearchMode: 'Muuta hakutapaa',
  clearFilter: 'Tyhjennä suodatin',
  clearSearch: 'Tyhjennä haku',
  clearSort: 'Tyhjennä lajittelu',
  clickToCopy: 'Kopioi napsauttamalla',
  collapse: 'Supista',
  collapseAll: 'Supista kaikki',
  columnActions: 'Saraketoiminnot',
  copiedToClipboard: 'Kopioitu leikepöydälle',
  dropToGroupBy: 'Pudota tähän ryhmitelläksesi sarakkeen {column} mukaan',
  edit: 'Muokkaa',
  expand: 'Laajenna',
  expandAll: 'Laajenna kaikki',
  filterArrIncludes: 'Sisältää',
  filterArrIncludesAll: 'Sisältää kaikki',
  filterArrIncludesSome: 'Sisältää',
  filterBetween: 'Välillä',
  filterBetweenInclusive: 'Välillä mukaan lukien',
  filterByColumn: 'Suodata sarakkeen {column} mukaan',
  filterContains: 'Sisältää',
  filterEmpty: 'Tyhjä',
  filterEndsWith: 'Loppuu',
  filterEquals: 'On yhtä kuin',
  filterEqualsString: 'On yhtä kuin',
  filterFuzzy: 'Sumea',
  filterGreaterThan: 'Enemmän kuin',
  filterGreaterThanOrEqualTo: 'Enemmän tai yhtä paljon kuin',
  filterInNumberRange: 'Välillä',
  filterIncludesString: 'Sisältää',
  filterIncludesStringSensitive: 'Sisältää',
  filterLessThan: 'Vähemmän kuin',
  filterLessThanOrEqualTo: 'Vähemmän tai yhtä paljon kuin',
  filterMode: 'Suodattimen tila: {filterType}',
  filterNotEmpty: 'Ei tyhjä',
  filterNotEquals: 'Ei ole yhtä kuin',
  filterStartsWith: 'Alkaa',
  filterWeakEquals: 'On yhtä kuin',
  filteringByColumn: 'Suodatetaan sarakkeen {column} mukaan - {filterType} {filterValue}',
  goToFirstPage: 'Siirry ensimmäiselle sivulle',
  goToLastPage: 'Siirry viimeiselle sivulle',
  goToNextPage: 'Siirry seuraavalle sivulle',
  goToPreviousPage: 'Siirry edelliselle sivulle',
  grab: 'Nappaa',
  groupByColumn: 'Ryhmittele sarakkeen {column} mukaan',
  groupedBy: 'Ryhmitelty sarakkeella ',
  hideAll: 'Piilota kaikki',
  hideColumn: 'Piilota sarake {column}',
  max: 'Maksimi',
  min: 'Minimi',
  move: 'Siirrä',
  noRecordsToDisplay: 'Ei näytettäviä tietueita',
  noResultsFound: 'Ei tuloksia',
  of: '/',
  or: 'tai',
  pinToLeft: 'Kiinnitä vasemmalle',
  pinToRight: 'Kiinnitä oikealle',
  resetColumnSize: 'Nollaa sarakkeen koko',
  resetOrder: 'Nollaa järjestys',
  rowActions: 'Rivitoiminnot',
  rowNumber: '#',
  rowNumbers: 'Rivinumerot',
  rowsPerPage: 'Rivejä per sivu',
  save: 'Tallenna',
  search: 'Etsi',
  selectedCountOfRowCountRowsSelected:
    '{selectedCount}/{rowCount} rivi(ä) valittu',
  select: 'Valitse',
  showAll: 'Näytä kaikki',
  showAllColumns: 'Näytä kaikki sarakkeet',
  showHideColumns: 'Näytä/piilota sarakkeita',
  showHideFilters: 'Näytä/piilota suodattimet',
  showHideSearch: 'Näytä/piilota haku',
  sortByColumnAsc: 'Järjestä sarakkeen {column} mukaan nousevasti',
  sortByColumnDesc: 'Järjestä sarakkeen {column} mukaan laskevasti',
  sortedByColumnAsc: 'Järjestetty sarakkeen {column} mukaan nousevasti',
  sortedByColumnDesc: 'Järjestetty sarakkeen {column} mukaan laskevasti',
  thenBy: ', sitten ',
  toggleDensity: 'Vaihda tiheyttä',
  toggleFullScreen: 'Vaihda kokoruututila',
  toggleSelectAll: 'Vaihda valitse kaikki',
  toggleSelectRow: 'Vaihda valitse rivi',
  toggleVisibility: 'Vaihda näkyvyys',
  ungroupByColumn: 'Poista ryhmittely sarakkeen {column} mukaan',
  unpin: 'Poista kiinnitys',
  unpinAll: 'Poista kiinnitys kaikilta',
  unsorted: 'Järjestämätön',
};

==> material-react-table-1.11.1.tgz: package/src/_locales/fi.ts <==
import type { MRT_Localization } from '../MaterialReactTable';

export const MRT_Localization_FI: MRT_Localization = {
  actions: 'Toiminnot',
  and: 'ja',
  cancel: 'Peruuta',
  changeFilterMode: 'Muuta suodattimen tilaa',
  changeSearchMode: 'Muuta hakutapaa',
  clearFilter: 'Tyhjennä suodatin',
  clearSearch: 'Tyhjennä haku',
  clearSort: 'Tyhjennä lajittelu',
  clickToCopy: 'Kopioi napsauttamalla',
  collapse: 'Supista',
  collapseAll: 'Supista kaikki',
  columnActions: 'Saraketoiminnot',
  copiedToClipboard: 'Kopioitu leikepöydälle',
  dropToGroupBy: 'Pudota tähän ryhmitelläksesi sarakkeen {column} mukaan',
  edit: 'Muokkaa',
  expand: 'Laajenna',
  expandAll: 'Laajenna kaikki',
  filterArrIncludes: 'Sisältää',
  filterArrIncludesAll: 'Sisältää kaikki',
  filterArrIncludesSome: 'Sisältää',
  filterBetween: 'Välillä',
  filterBetweenInclusive: 'Välillä mukaan lukien',
  filterByColumn: 'Suodata sarakkeen {column} mukaan',
  filterContains: 'Sisältää',
  filterEmpty: 'Tyhjä',
  filterEndsWith: 'Loppuu',
  filterEquals: 'On yhtä kuin',
  filterEqualsString: 'On yhtä kuin',
  filterFuzzy: 'Sumea',
  filterGreaterThan: 'Enemmän kuin',
  filterGreaterThanOrEqualTo: 'Enemmän tai yhtä paljon kuin',
  filterInNumberRange: 'Välillä',
  filterIncludesString: 'Sisältää',
  filterIncludesStringSensitive: 'Sisältää',
  filterLessThan: 'Vähemmän kuin',
  filterLessThanOrEqualTo: 'Vähemmän tai yhtä paljon kuin',
  filterMode: 'Suodattimen tila: {filterType}',
  filterNotEmpty: 'Ei tyhjä',
  filterNotEquals: 'Ei ole yhtä kuin',
  filterStartsWith: 'Alkaa',
  filterWeakEquals: 'On yhtä kuin',
  filteringByColumn:
    'Suodatetaan sarakkeen {column} mukaan - {filterType} {filterValue}',
  goToFirstPage: 'Siirry ensimmäiselle sivulle',
  goToLastPage: 'Siirry viimeiselle sivulle',
  goToNextPage: 'Siirry seuraavalle sivulle',
  goToPreviousPage: 'Siirry edelliselle sivulle',
  grab: 'Nappaa',
  groupByColumn: 'Ryhmittele sarakkeen {column} mukaan',
  groupedBy: 'Ryhmitelty sarakkeella ',
  hideAll: 'Piilota kaikki',
  hideColumn: 'Piilota sarake {column}',
  max: 'Maksimi',
  min: 'Minimi',
  move: 'Siirrä',
  noRecordsToDisplay: 'Ei näytettäviä tietueita',
  noResultsFound: 'Ei tuloksia',
  of: '/',
  or: 'tai',
  pinToLeft: 'Kiinnitä vasemmalle',
  pinToRight: 'Kiinnitä oikealle',
  resetColumnSize: 'Nollaa sarakkeen koko',
  resetOrder: 'Nollaa järjestys',
  rowActions: 'Rivitoiminnot',
  rowNumber: '#',
  rowNumbers: 'Rivinumerot',
  rowsPerPage: 'Rivejä per sivu',
  save: 'Tallenna',
  search: 'Etsi',
  selectedCountOfRowCountRowsSelected:
    '{selectedCount}/{rowCount} rivi(ä) valittu',
  select: 'Valitse',
  showAll: 'Näytä kaikki',
  showAllColumns: 'Näytä kaikki sarakkeet',
  showHideColumns: 'Näytä/piilota sarakkeita',
  showHideFilters: 'Näytä/piilota suodattimet',
  showHideSearch: 'Näytä/piilota haku',
  sortByColumnAsc: 'Järjestä sarakkeen {column} mukaan nousevasti',
  sortByColumnDesc: 'Järjestä sarakkeen {column} mukaan laskevasti',
  sortedByColumnAsc: 'Järjestetty sarakkeen {column} mukaan nousevasti',
  sortedByColumnDesc: 'Järjestetty sarakkeen {column} mukaan laskevasti',
  thenBy: ', sitten ',
  toggleDensity: 'Vaihda tiheyttä',
  toggleFullScreen: 'Vaihda kokoruututila',
  toggleSelectAll: 'Vaihda valitse kaikki',
  toggleSelectRow: 'Vaihda valitse rivi',
  toggleVisibility: 'Vaihda näkyvyys',
  ungroupByColumn: 'Poista ryhmittely sarakkeen {column} mukaan',
  unpin: 'Poista kiinnitys',
  unpinAll: 'Poista kiinnitys kaikilta',
  unsorted: 'Järjestämätön',
};
